"cViz.mergeSVG" <-
function(chromFile, trackFilesList, outFile)
{
    ### MAKE A CHROMOSOME NODE
    chromNode <- xmlTreeParse(chromFile)
    chromNodeSize <- xmlSize(xmlRoot(chromNode))

    ### GET height AND SAVE AS A delta
    curNode <- chromNode$doc$children$svg
    chrHeight <- as.numeric( xmlAttrs( curNode )[["height"]])
    trackFilesListNumber <- length(trackFilesList)
    tempChildNode <- xmlTreeParse(trackFilesList[1])$doc$children$svg
    delta <- as.numeric( xmlAttrs(tempChildNode)[["height"]])

    ### MAKE A ROOT NODE AND RESET height
    rootAttrs <- xmlAttrs( curNode )
    ### APPEND NAME SPACE
    rootAttrs <- append(rootAttrs, "http://www.w3.org/1999/xlink")
    names(rootAttrs)[length(rootAttrs)] <- "xmlns\:xlink"
    rootNode <- xmlNode("svg", attrs=rootAttrs ) 
    rootNode <- cViz.incSingleAttrValue(rootNode, 
                 "height", delta*trackFilesListNumber)          
    rootNode <- cViz.incSVGviewBoxValue(rootNode, 
                  delta*trackFilesListNumber)                   

    ### APPEND CHROMOSOMAL BAND NODES
    for(i in 1:chromNodeSize) {                    
       rootNode <- append.XMLNode(rootNode,  curNode[[i]])
    } 

    ### ATTACH OTHER TRACK FILES
    for(i in 1:trackFilesListNumber) { 
       moveDown <- chrHeight + i*delta       
       
       trackNode <- xmlTreeParse(trackFilesList[i], addAttributeNamespaces=T)
       useNode <- xmlRoot(trackNode)$children$use
       
       groupChildren <- xmlRoot(trackNode)$children$g
  
       ### CREATE NEW GROUP NODE
       newGroupNode <- xmlNode("g", attrs=xmlAttrs(groupChildren) )

       ### UPDATE GROUP CHILDREN height
       childList <- xmlChildren(groupChildren)
       childNames <- names(childList)
       tagNum <- xmlSize(groupChildren)
       newInfo <- 0
       
       for(j in 1:tagNum) {
           if(childNames[j] == "rect") {
                childList[[j]] <- cViz.incSingleAttrValue(childList[[j]], "y", moveDown) 
           }
           if(childNames[j] == "polyline") {
                childList[[j]] <- cViz.incPolylineAttrValue(childList[[j]], moveDown)
                newInfo <- strsplit(xmlAttrs(childList[[j]])[["points"]], " ")[[1]][3]                
           }    
           if(childNames[j] == "text") {
               childList[[j]] <- cViz.incTextAttrValue(childList[[j]], moveDown) 
           }               
           
           if((i==1) && (j==1)) {
               newInfo <- xmlAttrs(childList[[j]])[["y"]]
           }         
                    
           newGroupNode <- append.XMLNode(newGroupNode, childList[[j]])        
       }
    
       ### APPEND NEW GROUP NODE TO THE ROOT NODE
       rootNode <- append.XMLNode(rootNode, newGroupNode)
       
       ### APPEND use NODE TO THE ROOT NODE
       useNode <- xmlRoot(trackNode)$children$use
       useNode <- cViz.incSingleAttrValue(useNode, "info", newInfo)
       rootNode <- append.XMLNode(rootNode, useNode)
   }

   ### WRITE INTO A FILE
   file.create(outFile)
   write("<?xml version=\"1.0\"?>", file=outFile, append=F)   
   cat(toString(rootNode), file=outFile, append=T)                 
}

